@@ -33,9 +33,11 @@ from werkzeug.datastructures import CombinedMultiDict, MultiDict
 import logging
 log = logging.getLogger("fsa")
 
-# module version…
-VERSION = "4.3.1"
-VERSION_NUM = (4, 3, 1)
+# get module version
+__version__ = "4.5.0"
+# FIXME currently broken because of dependency issues with typing_extensions
+# import pkg_resources as pkg  # type: ignore
+# __version__ = pkg.require("FlaskSimpleAuth")[0].version
 
 
 class AuthException(BaseException):
@@ -309,7 +311,8 @@ _DIRECTIVES = {
     "FSA_TOKEN_LENGTH", "FSA_TOKEN_NAME", "FSA_REALM",
     "FSA_TOKEN_SECRET", "FSA_TOKEN_SIGN", "FSA_TOKEN_TYPE",
     "FSA_TOKEN_RENEWAL", "FSA_URL_NAME", "FSA_USER_IN_GROUP",
-    "FSA_LOGGING_LEVEL",
+    "FSA_LOGGING_LEVEL", "FSA_CORS", "FSA_CORS_OPTIONS",
+    "FSA_PASSWORD_LEN", "FSA_PASSWORD_RE",
 }
 
 
@@ -363,7 +366,7 @@ class FlaskSimpleAuth:
         if res.status_code < 400 and self._need_authorization:
             method, path = request.method, request.path
             log.warning(f"missing authorization on {method} {path}")
-            if self._check:
+            if self._check and not (self._cors and method == "OPTIONS"):
                 return self._Resp("missing authorization check", 500)
         return res
 
@@ -500,6 +503,12 @@ class FlaskSimpleAuth:
         self._mode = conf.get("FSA_MODE", "lazy")
         assert self._mode in ("always", "lazy", "all")
         self._check: bool = conf.get("FSA_CHECK", True)
+        # for web apps…
+        self._cors: bool = conf.get("FSA_CORS", False)
+        self._cors_options: Dict[str, Any] = conf.get("FSA_CORS_OPTIONS", {})
+        if self._cors:
+            from flask_cors import CORS  # type: ignore
+            CORS(self._app, **self._cors_options)
         self._maxsize = conf.get("FSA_CACHE_SIZE", 1024)
         import re
         self._skip_path = [re.compile(r).match for r in conf.get("FSA_SKIP_PATH", [])]
@@ -639,6 +648,7 @@ class FlaskSimpleAuth:
         #
         self.blueprints = self._app.blueprints
         self.debug = False
+        # portability tricks which generates mypy errors…
         if hasattr(self._app, '_blueprint_order'):
             # Flask 1.x
             self._blueprint_order = self._app._blueprint_order
@@ -681,6 +691,8 @@ class FlaskSimpleAuth:
                                 "bcrypt__default_ident": "2y"})
             from passlib.context import CryptContext  # type: ignore
             self._pm = CryptContext(schemes=[scheme], **options)
+        self._password_len: int = conf.get("FSA_PASSWORD_LEN", 0)
+        self._password_re: List[str] = conf.get("FSA_PASSWORD_RE", [])
 
     #
     # INHERITED HTTP AUTH
@@ -713,6 +725,8 @@ class FlaskSimpleAuth:
     #
     # FSA_PASSWORD_SCHEME: name of password scheme for passlib context
     # FSA_PASSWORD_OPTIONS: further options for passlib context
+    # FSA_PASSWORD_LEN: minimal length of provided passwords
+    # FSA_PASSWORD_RE: list of re a password must match
     #
     # NOTE passlib bcrypt is Apache compatible
     #
@@ -721,8 +735,15 @@ class FlaskSimpleAuth:
         """Verify whether a password is correct."""
         return self._pm.verify(pwd, ref)
 
-    def hash_password(self, pwd):
+    def hash_password(self, pwd, check=True):
         """Hash password according to the current password scheme."""
+        # check password quality
+        if check:
+            if len(pwd) < self._password_len:
+                raise AuthException(f"password is too short, must be at least {self._password_len}", 400)
+            for r in self._password_re:
+                if not re.search(r, pwd):
+                    raise AuthException(f"password must match {r}", 400)
         return self._pm.hash(pwd)
 
     def _check_password(self, user, pwd):
@@ -1157,7 +1178,8 @@ class FlaskSimpleAuth:
             def wrapper(*args, **kwargs):
 
                 # this cannot happen under normal circumstances
-                if self._need_authorization and self._check:  # pragma: no cover
+                if self._need_authorization and self._check and \
+                        not (self._cors and request.method == 'OPTIONS'):  # pragma: no cover
                     return self._Resp("missing authorization check", 500)
 
                 # translate request parameters to named function parameters
